exclude :test_addr, "needs investigation"
exclude :test_dgram_pair, "needs investigation"
exclude :test_epipe, "needs investigation"
exclude :test_fd_passing_race_condition, "needs investigation"
exclude :test_getpeereid, "needs investigation"
exclude :test_initialize, "needs investigation"
exclude :test_noname_recv_nonblock, "needs investigation"
exclude :test_noname_unpack_sockaddr_un, "needs investigation"
exclude :test_nul, "needs investigation"
exclude :test_socket_pair_with_block, "needs investigation"
exclude :test_too_long_path, "needs investigation"
